pub struct PresignedUrlOpts {
pub file_key: String,
pub expires_in: Option<i32>,
}Expand description
A structure representing the options to generate a presigned URL.
This structure holds the necessary information to create a presigned URL which can be used to access a file without requiring further authentication.
Fields
file_key: StringThe unique key of the file for which the presigned URL will be generated.
expires_in: Option<i32>Optional expiration time in seconds for the presigned URL.
If None, a default value will be used.